import {
  reactive,
  ref
} from "vue"
import request from '@/utils/request'
import { showDanger } from '@/utils'

export default () => {
  const loading = ref(false)
  const list = ref([])
  const page = reactive({})
  const detail = reactive({})
  const roomRole = reactive({})
  const roomAuthBox = reactive({})
  const roomKeyBox = reactive({})

  const getList = data => {
    loading.value = true
    request({
      loadingId: 'room.list',
      url: '/room/list',
      data: {
        pageNo: 1,
        pageSize: 10,
        ...data,
      }
    }).then(res => {
      const {
        pageNo,
        pageSize,
        endRow,
        result
      } = res || {}
      Object.assign(page, {
        pageNo,
        pageSize,
        endRow
      })
      list.value = pageNo <= 1 ? result : list.value.concat(list.value)
      loading.value = false
    }).catch(e => {
      console.error(e)
      loading.value = false
    })
  }

  // 房源详情--基础信息
  const getDetail = data => {
    request({
      loadingId: 'room.view',
      url: '/room/detail',
      params: {

        id:data,
      }
    }).then(res => {
      Object.assign(detail, res)
    }).catch(e => {
      console.error(e)
      showDanger('获取详情失败')
    })
  }

  // 角色人信息
  const getRole = data => {
    request({
      loadingId: 'room.role',
      url: '/room/role',
      params: {
        roomId:data,
      }
    }).then(res => {
      Object.assign(roomRole, res)
    }).catch(e => {
      console.error(e)
      showDanger('获取角色人失败')
    })
  }

  // 委托书信息
  const getAuth = data => {
    request({
      loadingId: 'room.auth',
      url: '/room/auth',
      params: {
        roomId: data,
      }
    }).then(res => {
      Object.assign(roomAuthBox, res)
    }).catch(e => {
      console.error(e)
      showDanger('获取委托书失败')
    })
  }

  // 钥匙信息
  const getKey = data => {
    request({
      loadingId: 'room.key',
      url: '/room/key',
      params: {
        roomId: data,
      }
    }).then(res => {
      Object.assign(roomKeyBox, res)
    }).catch(e => {
      console.error(e)
      showDanger('获取钥匙失败')
    })
  }

  // 敏感信息
  const getSecurity = id => {
    return  request({
        loadingId: 'room.security',
        url: '/room/security',
        params: {

          roomId:id,
        }
      }).then(res => {
        console.log(res, 'res')
        return res
      }).catch(e => {
        console.error(e)
      })
  }

  return {
    list,
    page,
    getList,
    detail,
    getDetail,
    getSecurity,
    loading,
    getRole,
    roomRole,
    roomAuthBox,
    getAuth,
    getKey,
    roomKeyBox,
  }
}